@@ -13,7 +13,7 @@ use Bat::Interpreter::Delegate::Executor::PartialDryRunner;
 use Bat::Interpreter::Delegate::LineLogger::Silent;
 use namespace::autoclean;
 
-our $VERSION = '0.020';    # VERSION
+our $VERSION = '0.021';    # VERSION
 
 # ABSTRACT: Pure perl interpreter for a small subset of bat/cmd files
 
@@ -202,7 +202,7 @@ sub _handle_special_command {
     if ( $type eq 'Goto' ) {
         my $label = $special_command_line->{'Goto'}{'Identifier'};
         $context->{'current_line'} .= 'GOTO ' . $label;
-        $self->_goto_label( $label, $context );
+        $self->_goto_label( $label, $context, 0 );
     }
 
     if ( $type eq 'Call' ) {
@@ -211,7 +211,7 @@ sub _handle_special_command {
         $token = $self->_adjust_path($token);
         $context->{'current_line'} .= 'CALL ' . $token;
         if ( $token =~ /^:/ ) {
-            $self->_goto_label( $token, $context );
+            $self->_goto_label( $token, $context, 1 );
         } else {
             ( my $first_word ) = $token =~ /\A([^:\s]+)/;
             if ( $first_word =~ /(\.[^.]+)$/ ) {
@@ -419,6 +419,7 @@ sub _goto_label {
     my $self    = shift();
     my $label   = shift();
     my $context = shift();
+    my $call    = shift();
     $label =~ s/^://;
     $label =~ s/ //g;
     if ( $context->{'LABEL_INDEX'}{$label} ) {
@@ -430,7 +431,9 @@ sub _goto_label {
                 $context->{'IP'} = $context->{'LABEL_INDEX'}{$label};
             }
         } else {
-            push @{ $context->{'STACK'} }, { IP => $context->{'IP'} };
+            if ($call) {
+                push @{ $context->{'STACK'} }, { IP => $context->{'IP'} };
+            }
             $context->{'IP'} = $context->{'LABEL_INDEX'}{$label};
         }
     } else {
@@ -468,7 +471,7 @@ Bat::Interpreter - Pure perl interpreter for a small subset of bat/cmd files
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
